#
# VISUALIZATION WITH PROSECTIONS - prosection matrix
#
# Main script
#
# Author: Tea Tusar, Jozef Stefan Institute, Slovenia (tea.tusar@ijs.si)
#
# This is a gnuplot script for visualizing an animated prosection matrix of the 4D approximation 
# sets of the DTLZ5(3,4) and DTLZ5(2,4) problems. To work, the scripts "prosections.matrix.t1.plt" and 
# "prosections.matrix.t2.f2.plt" must be placed in the same directory as this script. 
#
# Run this script in gnuplot using "load 'prosections.matrix.dtlz5.plt'". Change the visualization
# parameters below as needed.
#
# See the paper below for more information:
# T. Tusar and B. Filipic: Seeing 4D approximation sets in evolutionary multiobjective optimization.
#
reset
#
# PARAMETERS OF THE SCRIPT
#
# The file with the approximation set. One is set by default, but more can be visualized, too. 
# If you need more, add more "fileN = 'filename.txt'" lines, however note that this requires adding also 
# one line per set in the plot command in the "prosections.matrix.t2.f1.plt" script. 
#
file1 = "4d.dtlz5.3.4.txt"
file2 = "4d.dtlz5.2.4.txt"
#
# The strings to appear in the plot legend.
#
key1 = "DTLZ5(3,4)"
key2 = "DTLZ5(2,4)"
#
# The columns in the input files that correspond to the objectives (these should be the same in
# all files). 
#
col1 = 1
col2 = 2
col3 = 3
col4 = 4
#
# Min and max values of approximation sets for each objective. The min values automatically
# count as the origin of the prosections.
#
f1min = 0
f1max = 1
#
f2min = 0
f2max = 1
#
f3min = 0
f3max = 1
#
f4min = 0
f4max = 1
#
# Gnuplot point colors for each file.
# 
lt1 = 1
lt2 = 2
#
# Gnuplot point types for each file.
#
pt1 = 1
pt2 = 2
#
# The width of the section.
#
D = 0.05
#
# Min (A) and max (B) angles phi and the step (dA) for the animation. If you want to have a
# static plot, set A equal to B. All angles are given in degrees. 
#
A = 0
dA = 5
B = 90
# 
# GNUPLOT COMMANDS 
#
set key outside
set view 50,50
sizeone = 0.33
set angles degrees
#
tmp1(x) = (x < 1.5) ? f1min : f2min
tmp2(x) = (x < 2.5) ? tmp1(x) : f3min
getmin(x) = (x < 3.5) ? tmp2(x) : f4min
#
tmp3(x) = (x < 1.5) ? f1max : f2max
tmp4(x) = (x < 2.5) ? tmp3(x) : f3max
getmax(x) = (x < 3.5) ? tmp4(x) : f4max
#
tmp5(x) = (x < 1.5) ? col1 : col2
tmp6(x) = (x < 2.5) ? tmp5(x) : col3
getcol(x) = (x < 3.5) ? tmp6(x) : col4
#
template1 = "prosections.matrix.t1.plt"
template2 = "prosections.matrix.t2.f2.plt"
#
load template1