#
# VISUALIZATION WITH PROSECTIONS - single plot
#
# Main script
#
# Author: Tea Tusar, Jozef Stefan Institute, Slovenia (tea.tusar@ijs.si)
#
# This is a gnuplot script for visualizing animated prosections of the 4D approximation set
# of the DEB4DK problem. To work, the scripts "prosections.single.t1.plt" and "prosections.single.t2.f1.plt"
# must be placed in the same directory as this script. 
#
# Run this script in gnuplot using "load 'prosections.single.deb4dk.plt'". Change the visualization
# parameters below as needed.
#
# See the paper below for more information:
# T. Tusar and B. Filipic: Seeing 4D approximation sets in evolutionary multiobjective optimization.
#
reset
#
# PARAMETERS OF THE SCRIPT
#
# The file with the approximation set. One is set by default, but more can be visualized, too. 
# If you need more, add more "fileN = 'filename.txt'" lines, however note that this requires adding also 
# one line per set in the plot command in the "prosections.single.t2.f1.plt" script. 
#
file1 = "4d.deb4dk.txt"
#
# The strings to appear in the plot legend.
#
key1 = "DEB4DK"
#
# The columns in the input files that correspond to the objectives (these should be the same in
# all files).
#
col1 = 1
col2 = 2
col3 = 3
col4 = 4
#
# The objectives as used in this visualization (obj1 and obj2 get projected).
#
obj1 = 1
obj2 = 4
obj3 = 2
obj4 = 3
#
# Min and max values of approximation sets for each objective. The min values automatically
# count as the origin of the prosections.
#
f1min = 0
f1max = 50
#
f2min = 0
f2max = 50
#
f3min = 0
f3max = 50
#
f4min = 0
f4max = 50
#
# Gnuplot point colors for each file.
# 
lt1 = 1
#
# Gnuplot point types for each file.
#
pt1 = 1
#
# The width of the section.
#
D = 2.5
#
# Min (A) and max (B) angles phi and the step (dA) for the animation. If you want to have a
# static plot, set A equal to B.
#
A = 0
dA = 5
B = 90
#
# GNUPLOT COMMANDS 
#
set key inside top right
set view 50,50
sizeone = 1
set angles degrees
#
tmp1(x) = (x < 1.5) ? f1min : f2min
tmp2(x) = (x < 2.5) ? tmp1(x) : f3min
getmin(x) = (x < 3.5) ? tmp2(x) : f4min
#
tmp3(x) = (x < 1.5) ? f1max : f2max
tmp4(x) = (x < 2.5) ? tmp3(x) : f3max
getmax(x) = (x < 3.5) ? tmp4(x) : f4max
#
tmp5(x) = (x < 1.5) ? col1 : col2
tmp6(x) = (x < 2.5) ? tmp5(x) : col3
getcol(x) = (x < 3.5) ? tmp6(x) : col4
#
template1 = "prosections.single.t1.plt"
template2 = "prosections.single.t2.f1.plt"
#
load template1